@@ -105,7 +105,7 @@ const CodeEditor = () => {
     const codeToInsert = useSelector((state: RootState) => state.codeEditor.codeToInsert);
 
     const shortcutKeysConfig = useSelector(
-        (state: RootState) => state.projectManager.configs.shortcut_keys
+        (state: RootState) => state.projectManager.configs.code_editor_shortcut
     );
 
     const lineStatusUpdate = useSelector(
@@ -260,6 +260,7 @@ const CodeEditor = () => {
             resetEditorState(inViewID, view);
             setCodeReloading(true);
         }
+        setLangExtensions(getLangExtenstions(inViewID));
     }, [inViewID]);
 
     /**
