@@ -1,8 +1,9 @@
 import React, { useEffect, useRef } from "react";
+import { ProjectCommand } from "../../interfaces/IFileManager";
 import { ContextMenuNewItem } from "../StyledComponents";
 import CypressIds from "../tests/CypressIds";
 
-const NewItemInput = ({ handleKeyPress }) => {
+const NewItemInput = ({ handleKeyPress, command }) => {
     const newItemRef = useRef();
 
     useEffect(() => {
@@ -16,10 +17,10 @@ const NewItemInput = ({ handleKeyPress }) => {
     return (
         <ContextMenuNewItem
             inputRef={newItemRef}
-            defaultValue='.py'
+            defaultValue={command == ProjectCommand.create_file ? ".py" : ""}
             data-cy={CypressIds.newFileItem}
             onKeyDown={(event: React.KeyboardEvent) =>
-                handleKeyPress(event, newItemRef.current.value)
+                handleKeyPress(event, newItemRef.current.value, command)
             }
         />
     );
