@@ -5,20 +5,39 @@ import {
     IFileMetadata,
     IProjectMetadata,
 } from "../../lib/interfaces/IFileManager";
-import { IConfigs, IShorcutKey, ViewMode, IEditorConfigs } from '../../lib/interfaces/IApp';
 
-const originalShortcutKeys: IShorcutKey = {
+import {
+    IAppShortcutKey,
+    IConfigs,
+    IEditorShortcutKey,
+    ViewMode,
+    IEditorConfigs,
+    IDataFrameManagerConfigs,
+} from "../../lib/interfaces/IApp";
+
+const originalEditorShortcutKeys: IEditorShortcutKey = {
     run_queue: "Mod-l",
     set_group: "Mod-k",
     set_ungroup: "Mod-j",
 };
 
+const originalAppShortcutKeys: IAppShortcutKey = {
+    autocompletion_tooggle: "shift + a",
+    lint_tooggle: "shift + l",
+    hover_tooggle: "shift + h",
+};
+
 const codeEditorConfigs: IEditorConfigs = {
     lint: true,
     hover: true,
     autocompletion: true,
 };
 
+const dataframeManagerConfigs: IDataFrameManagerConfigs = {
+    show_exec_text: false,
+    auto_display_data: true,
+};
+
 type ProjectManagerState = {
     openFiles: { [id: string]: IFileMetadata };
     activeProject: IProjectMetadata | null;
@@ -52,8 +71,10 @@ const initialState: ProjectManagerState = {
     serverSynced: false,
     configs: {
         view_mode: ViewMode.VERTICAL,
-        shortcut_keys: originalShortcutKeys,
+        code_editor_shortcut: originalEditorShortcutKeys,
+        app_shortcut: originalAppShortcutKeys,
         code_editor: codeEditorConfigs,
+        dataframe_manager: dataframeManagerConfigs,
     },
 };
 
